summaryrefslogtreecommitdiffstats
path: root/kttsd/filters/sbd/sbdconf.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kttsd/filters/sbd/sbdconf.cpp')
-rw-r--r--kttsd/filters/sbd/sbdconf.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/kttsd/filters/sbd/sbdconf.cpp b/kttsd/filters/sbd/sbdconf.cpp
index 5b1fb6d..3b32764 100644
--- a/kttsd/filters/sbd/sbdconf.cpp
+++ b/kttsd/filters/sbd/sbdconf.cpp
@@ -232,10 +232,10 @@ void SbdConf::slotReButton_clicked()
void SbdConf::slotLanguageBrowseButton_clicked()
{
// Create a TQHBox to host KListView.
TQHBox* hBox = new TQHBox(m_widget, "SelectLanguage_hbox");
- // Create a KListView and fill with all known languages.
- KListView* langLView = new KListView(hBox, "SelectLanguage_lview");
+ // Create a TDEListView and fill with all known languages.
+ TDEListView* langLView = new TDEListView(hBox, "SelectLanguage_lview");
langLView->addColumn(i18n("Language"));
langLView->addColumn(i18n("Code"));
langLView->setSelectionMode(TQListView::Extended);
@@ -246,7 +246,7 @@ void SbdConf::slotLanguageBrowseButton_clicked()
TQString charSet;
TQString language;
// Blank line so user can select no language.
- TQListViewItem* item = new KListViewItem(langLView, "", "");
+ TQListViewItem* item = new TDEListViewItem(langLView, "", "");
if (m_languageCodeList.isEmpty()) item->setSelected(true);
const int allLocalesCount = allLocales.count();
for (int ndx=0; ndx < allLocalesCount; ++ndx)
@@ -256,7 +256,7 @@ void SbdConf::slotLanguageBrowseButton_clicked()
language = TDEGlobal::locale()->twoAlphaToLanguageName(languageCode);
if (!countryCode.isEmpty()) language +=
" (" + TDEGlobal::locale()->twoAlphaToCountryName(countryCode)+")";
- TQListViewItem* item = new KListViewItem(langLView, language, locale);
+ TQListViewItem* item = new TDEListViewItem(langLView, language, locale);
if (m_languageCodeList.contains(locale)) item->setSelected(true);
}
// Sort by language.
@@ -288,7 +288,7 @@ void SbdConf::slotLanguageBrowseButton_clicked()
}
}
delete dlg;
// TODO: Also delete KListView and TQHBox?
if (dlgResult != TQDialog::Accepted) return;
language = "";
for ( uint ndx=0; ndx < m_languageCodeList.count(); ++ndx)
@@ -232,10 +232,10 @@ void SbdConf::slotReButton_clicked()
void SbdConf::slotLanguageBrowseButton_clicked()
{
- // Create a TQHBox to host KListView.
+ // Create a TQHBox to host TDEListView.
TQHBox* hBox = new TQHBox(m_widget, "SelectLanguage_hbox");
@@ -288,7 +288,7 @@ void SbdConf::slotLanguageBrowseButton_clicked()
}
delete dlg;
- // TODO: Also delete KListView and TQHBox?
+ // TODO: Also delete TDEListView and TQHBox?
if (dlgResult != TQDialog::Accepted) return;
language = "";